import { KnapsackRendererWebpackBase } from '@knapsack/renderer-webpack-base';
import { Except } from '@knapsack/utils';
import { KsJsImport } from '@knapsack/types';
import { KnapsackRenderParams, KnapsackTemplateRenderer, KnapsackConfig, Patterns, KnapsackTemplateRendererBase, KnapsackTemplateRendererResults } from '@knapsack/app/types';

type DemoWrapperProps = {
    children: React.ReactNode;
    patternsUsed: {
        patternId: string;
        templateId: string;
        demoId?: string;
    }[];
} & Except<KnapsackRenderParams, 'patternManifest'>;
declare class KnapsackReactRenderer extends KnapsackRendererWebpackBase implements KnapsackTemplateRenderer {
    /**
     * `react.js` & `react-dom.js` root relative paths
     */
    assets: string[];
    babelConfig: Record<string, unknown>;
    creators: KnapsackTemplateRenderer['creators'];
    private demoWrapperPath;
    private disableReactStrictMode?;
    constructor({ webpackConfig, demoWrapperPath, id, disableReactStrictMode, }?: {
        webpackConfig?: ConstructorParameters<typeof KnapsackRendererWebpackBase>[0]['webpackConfig'];
        demoWrapperPath?: string;
        /** When using React v18+, this option allows a workspace to _disable_ React's Strict Mode from running in Knapsack's React Renderer (StrictMode is enabled by default).
         *
         * See https://reactjs.org/docs/strict-mode.html for more info
         * */
        disableReactStrictMode?: boolean;
        /** Don't set if calling from `knapsack.config.js`, only use if creating a new Renderer based on the React Renderer */
        id?: string;
    });
    init(opt: {
        config: KnapsackConfig;
        patterns: Patterns;
        cacheDir: string;
    }): Promise<void>;
    getMeta: KnapsackTemplateRendererBase['getMeta'];
    changeCase(str: string): string;
    createWebpackConfig(): ReturnType<KnapsackRendererWebpackBase['createWebpackConfig']>;
    getJsImports(): ReturnType<KnapsackRendererWebpackBase['getJsImports']>;
    prepClientRenderResults({ usage, demoApp, imports: xImports, renderOptions: { pattern, template, demo }, }: {
        usage: string;
        demoApp: string;
        imports: KsJsImport[];
        renderOptions: KnapsackRenderParams;
    }): Promise<KnapsackTemplateRendererResults>;
    render(opt: KnapsackRenderParams): Promise<KnapsackTemplateRendererResults>;
    getUsageAndImports(opt: KnapsackRenderParams): Promise<{
        usage: string;
        imports: KsJsImport[];
    }>;
    getUsage(opt: KnapsackRenderParams): Promise<string>;
    inferSpec: KnapsackTemplateRendererBase['inferSpec'];
    watch(opt: Parameters<KnapsackTemplateRendererBase['watch']>[0]): Promise<void>;
    getTemplateMeta: KnapsackTemplateRendererBase['getTemplateMeta'];
    alterTemplateMetaFiles: KnapsackTemplateRendererBase['alterTemplateMetaFiles'];
    getTemplateSuggestions({ newPath, }: Parameters<KnapsackTemplateRendererBase['getTemplateSuggestions']>[0]): ReturnType<KnapsackTemplateRendererBase['getTemplateSuggestions']>;
}

export { type DemoWrapperProps, KnapsackReactRenderer };
